package Task::CPANAuthors::STRO;

# $Id: PPMCreator.pm 9 2009-10-18 16:07:28Z stro $

use strict;
use warnings;

our $VERSION = '2009.1018';

1;

=head1 NAME

Task::CPANAuthors::STRO - modules required by PPMCreator.

=head1 SYNOPSIS

 ppm install Task::CPANAuthors::STRO::PPMCreator

=head1 DESCRIPTION

"Task" for installing modules required by PPMCreator.

=head1 AUTHOR

Serguei Trouchelle E<lt>F<stro@cpan.org>E<gt>

=cut 
